@@ -38,7 +38,7 @@
 extern "C" {
 #endif
 
-#define LIBGNUTLS_VERSION "1.1.16"
+#define LIBGNUTLS_VERSION "1.1.17"
 
 #ifndef HAVE_SIZE_T
 # define HAVE_SIZE_T
@@ -816,12 +816,15 @@ void gnutls_anon_set_params_function(gnutls_certificate_credentials_t res,
 #define GNUTLS_E_CONSTRAINT_ERROR -101
 
 #define GNUTLS_E_BASE64_ENCODING_ERROR -201
-#define GNUTLS_E_INCOMPATIBLE_GCRYPT_LIBRARY -202
+#define GNUTLS_E_INCOMPATIBLE_GCRYPT_LIBRARY -202 /* obsolete */
+#define GNUTLS_E_INCOMPATIBLE_CRYPTO_LIBRARY -202
 #define GNUTLS_E_INCOMPATIBLE_LIBTASN1_LIBRARY -203
 
 #define GNUTLS_E_OPENPGP_KEYRING_ERROR -204
 #define GNUTLS_E_X509_UNSUPPORTED_OID -205
 
+#define GNUTLS_E_RANDOM_FAILED -206
+
 #define GNUTLS_E_UNIMPLEMENTED_FEATURE -1250
 
 
